@@ -1,31 +1,31 @@
-#' @title Launch the \pkg{shinybrms} Shiny app
+#' @title Launch the \bold{shinybrms} Shiny app
 #'
-#' @description This function launches the \pkg{shinybrms} Shiny app.
+#' @description This function launches the \bold{shinybrms} Shiny app.
 #'
 #' @param \dots Arguments passed to [shiny::runApp()]. For example, in order to force launching the
 #'   Shiny app in the system's default web browser (even if using RStudio), set argument
 #'   `launch.browser` to `TRUE`.
 #'
-#' @note The following global options are introduced by \pkg{shinybrms}:
+#' @note The following global options are introduced by \bold{shinybrms}:
 #'
 #' * `shinybrms.prog_browser`: The value for the global option `browser` to be used for opening the
 #' [Stan](https://mc-stan.org/) progress file (an HTML file). Defaults to option `browser` (see
 #' [base::options()]). Note that RStudio's default for option `browser` cannot be used for the Stan
-#' progress file. Therefore, \pkg{shinybrms} automatically redefines RStudio's default for option
+#' progress file. Therefore, \bold{shinybrms} automatically redefines RStudio's default for option
 #' `browser` to fix this issue.
 #' * `shinybrms.shinystan_browser`: The value for the global option
-#' `browser` to be used for opening the \pkg{shinystan} app. Defaults to option `browser` (see
+#' `browser` to be used for opening the \bold{shinystan} app. Defaults to option `browser` (see
 #' [base::options()]). Note that RStudio's default for option `browser` cannot be used for opening
-#' the \pkg{shinystan} app from within \pkg{shinybrms}. Therefore, \pkg{shinybrms} automatically
+#' the \bold{shinystan} app from within \bold{shinybrms}. Therefore, \bold{shinybrms} automatically
 #' redefines RStudio's default for option `browser` to fix this issue.
 #'
-#' The only other global option used by \pkg{shinybrms} is `mc.cores` (see [base::options()]): If
-#' option `mc.cores` is set, then the advanced option "Cores" (in the \pkg{shinybrms} app) defaults
+#' The only other global option used by \bold{shinybrms} is `mc.cores` (see [base::options()]): If
+#' option `mc.cores` is set, then the advanced option "Cores" (in the \bold{shinybrms} app) defaults
 #' to the value of this option. If option `mc.cores` is not set, then the advanced option "Cores"
 #' defaults to the value returned by [parallel::detectCores()].
 #'
-#' Note that \pkg{shinystan}'s global option `shinystan.rstudio` (see
-#' [shinystan::launch_shinystan()]) may not be used here as \pkg{shinystan} is called from an
+#' Note that \bold{shinystan}'s global option `shinystan.rstudio` (see
+#' [shinystan::launch_shinystan()]) may not be used here as \bold{shinystan} is called from an
 #' external \R process where RStudio's browsers are not available.
 #'
 #' @return `TRUE` (invisible).
@@ -49,6 +49,8 @@ launch_shinybrms <- function(...){
   if(FALSE){
     # Just a dummy call of a "brms" function for avoiding a NOTE in CRAN checks on some platforms:
     brms::expp1(0)
+    # Just a dummy call of an "rstan" function for avoiding a NOTE in CRAN checks on some platforms:
+    rstan::set_cppo()
   }
   return(invisible(TRUE))
 }
